==> mediawiki-1.18.1.tgz: mediawiki/extensions/ConfirmEdit/ConfirmEdit.alias.php <==
<?php
/**
 * Aliases for special pages
 *
 * @file
 * @ingroup Extensions
 */

$specialPageAliases = array();

/** English (English) */
$specialPageAliases['en'] = array(
	'Captcha' => array( 'Captcha' ),
);

/** Arabic (العربية) */
$specialPageAliases['ar'] = array(
	'Captcha' => array( 'كابتشا' ),
);

/** Egyptian Spoken Arabic (مصرى) */
$specialPageAliases['arz'] = array(
	'Captcha' => array( 'كابتشا' ),
);

/** Esperanto (Esperanto) */
$specialPageAliases['eo'] = array(
	'Captcha' => array( 'Kontraŭspamilo' ),
);

/** Estonian (Eesti) */
$specialPageAliases['et'] = array(
	'Captcha' => array( 'Robotilõks' ),
);

/** Persian (فارسی) */
$specialPageAliases['fa'] = array(
	'Captcha' => array( 'کپچا' ),
);

/** Finnish (Suomi) */
$specialPageAliases['fi'] = array(
	'Captcha' => array( 'Ihmiskäyttäjävarmistus' ),
);

/** Japanese (日本語) */
$specialPageAliases['ja'] = array(
	'Captcha' => array( 'キャプチャ' ),
);

/** Colognian (Ripoarisch) */
$specialPageAliases['ksh'] = array(
	'Captcha' => array( 'Kaptscha' ),
);

/** Macedonian (Македонски) */
$specialPageAliases['mk'] = array(
	'Captcha' => array( 'Капча' ),
);

/** Malayalam (മലയാളം) */
$specialPageAliases['ml'] = array(
	'Captcha' => array( 'ക്യാപ്ച' ),
);

/** Serbian Cyrillic ekavian (‪Српски (ћирилица)‬) */
$specialPageAliases['sr-ec'] = array(
	'Captcha' => array( 'Потврдни_код' ),
);

/** Simplified Chinese (‪中文(简体)‬) */
$specialPageAliases['zh-hans'] = array(
	'Captcha' => array( '验证码' ),
);

/** Traditional Chinese (‪中文(繁體)‬) */
$specialPageAliases['zh-hant'] = array(
	'Captcha' => array( '驗證碼' ),
);

/**
 * For backwards compatibility with MediaWiki 1.15 and earlier.
 */
$aliases =& $specialPageAliases;

==> mediawiki-1.19.2p0.tgz: mediawiki/extensions/ConfirmEdit/ConfirmEdit.alias.php <==
<?php
/**
 * Aliases for special pages
 *
 * @file
 * @ingroup Extensions
 */

$specialPageAliases = array();

/** English (English) */
$specialPageAliases['en'] = array(
	'Captcha' => array( 'Captcha' ),
);

/** Arabic (العربية) */
$specialPageAliases['ar'] = array(
	'Captcha' => array( 'كابتشا' ),
);

/** Egyptian Spoken Arabic (مصرى) */
$specialPageAliases['arz'] = array(
	'Captcha' => array( 'كابتشا' ),
);

/** Esperanto (Esperanto) */
$specialPageAliases['eo'] = array(
	'Captcha' => array( 'Kontraŭspamilo' ),
);

/** Estonian (eesti) */
$specialPageAliases['et'] = array(
	'Captcha' => array( 'Robotilõks' ),
);

/** Persian (فارسی) */
$specialPageAliases['fa'] = array(
	'Captcha' => array( 'کپچا' ),
);

/** Finnish (suomi) */
$specialPageAliases['fi'] = array(
	'Captcha' => array( 'Ihmiskäyttäjävarmistus' ),
);

/** Galician (Galego) */
$specialPageAliases['gl'] = array(
	'Captcha' => array( 'Captcha' ),
);

/** Hindi (हिन्दी) */
$specialPageAliases['hi'] = array(
	'Captcha' => array( 'कैप्चा', 'कैपचा' ),
);

/** Japanese (日本語) */
$specialPageAliases['ja'] = array(
	'Captcha' => array( '画像認証' ),
);

/** Korean (한국어) */
$specialPageAliases['ko'] = array(
	'Captcha' => array( '캡차' ),
);

/** Colognian (Ripoarisch) */
$specialPageAliases['ksh'] = array(
	'Captcha' => array( 'Kaptscha' ),
);

/** Cornish (kernowek) */
$specialPageAliases['kw'] = array(
	'Captcha' => array( 'Captcha' ),
);

/** Macedonian (македонски) */
$specialPageAliases['mk'] = array(
	'Captcha' => array( 'Captcha' ),
);

/** Malayalam (മലയാളം) */
$specialPageAliases['ml'] = array(
	'Captcha' => array( 'ക്യാപ്ച' ),
);

/** Serbian (Cyrillic script) (‪српски (ћирилица)‬) */
$specialPageAliases['sr-ec'] = array(
	'Captcha' => array( 'Потврдни_код' ),
);

/** Cantonese (粵語) */
$specialPageAliases['yue'] = array(
	'Captcha' => array( '驗證碼' ),
);

/** Simplified Chinese (‪中文（简体）‬) */
$specialPageAliases['zh-hans'] = array(
	'Captcha' => array( '验证码' ),
);

/** Traditional Chinese (‪中文（繁體）‬) */
$specialPageAliases['zh-hant'] = array(
	'Captcha' => array( '驗證碼' ),
);
